#ifndef __VTKPLOTTING_HPP__
#define __VTKPLOTTING_HPP__

#include <string>

#include <vtkSmartPointer.h>
#include <vtkPolyData.h>

#include "linalg.hpp"
namespace kwantix{

  ///A class for creating VTK plots
  class vtkplot{

  public:
    /*! \brief Constructor performs a Delaunay triangulation on data
     * \param data - An \f$n \times 3\f$ matrix where the first two
     *               columns are points in the x-y plane on which a
     *               Delaunay triangulation will be done, and the
     *               third column is the value at this point.
     */
    vtkplot(const matrix& data);
    ///Defines the view direction when plotting.
    void set_view_direction(const vector& dir);
    ///Without changing the triangulation, update the values.
    void update_values(const vector& values);
    ///Enable offscreen plotting.
    void plot_offscreen(bool yesno);
    ///Set the base filename used for saving, to which numbers are appended.
    void set_base_filename(const std::string& basename);
    ///Actually do the plot, whether offscreen or onscreen.
    void plot() const;

  private:
    ///Base filename
    string basename;
    ///Direction from which to plot
    vector view_direction;
   ///The plot data
    vtkSmartPointer<vtkDelaunay2D> delaunay;
    ///Whether to plot offscreen or not
    bool offscreen;
  };

}

#endif //__VTKPLOTTING_HPP__
